python_igraph: Python bindings for igraph
=========================================

Description
-----------

igraph is a library for creating and manipulating graphs. It is intended
to be as powerful (ie. fast) as possible to enable the analysis of large
graphs.

License
-------

GPL version 2


Upstream Contact
----------------

http://igraph.org/python/

Dependencies
------------

-  python
-  igraph


Special Update/Build Instructions
---------------------------------
